==> qmmp-plugin-pack-1.4.0.tar.bz2: qmmp-plugin-pack-1.4.0/src/Visual/goom/translations/goom_plugin_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>GoomWidget</name>
    <message>
        <location filename="../goomwidget.cpp" line="137"/>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="187"/>
        <source>Refresh Rate</source>
        <translation>Päivitystaajuus</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="190"/>
        <source>60 fps</source>
        <translation>60 fps</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="191"/>
        <source>50 fps</source>
        <translation>50 fps</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="192"/>
        <source>25 fps</source>
        <translation>25 fps</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="198"/>
        <source>&amp;Show Title</source>
        <translation>&amp;Näytä nimike</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="201"/>
        <source>&amp;Full Screen</source>
        <translation>&amp;Koko näyttö</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="201"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>VisualGoomFactory</name>
    <message>
        <location filename="../visualgoomfactory.cpp" line="30"/>
        <source>Goom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="49"/>
        <source>About Goom Visual Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="50"/>
        <source>Qmmp Goom Visual Plugin</source>
        <translation>Qmmp:n Goom-visualisointiliitännäinen</translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="51"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Toteuttanut: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="52"/>
        <source>Based on the source code from the Goom project</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="53"/>
        <source>Goom project developers:</source>
        <translation>Goom-projektin kehittäjät:</translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="54"/>
        <source>Jean-Christophe Hoelt &lt;jeko@ios-software.com&gt;</source>
        <translation>Jean-Christophe Hoelt &lt;jeko@ios-software.com&gt;</translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="55"/>
        <source>Guillaume Borios &lt;gyom@ios-software.com&gt;</source>
        <translation>Guillaume Borios &lt;gyom@ios-software.com&gt;</translation>
    </message>
</context>
</TS>

==> qmmp-plugin-pack-1.5.3.tar.bz2: qmmp-plugin-pack-1.5.3/src/Visual/goom/translations/goom_plugin_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>GoomWidget</name>
    <message>
        <location filename="../goomwidget.cpp" line="137"/>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="187"/>
        <source>Refresh Rate</source>
        <translation>Virkistystaajuus</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="190"/>
        <source>60 fps</source>
        <translation>60 fps</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="191"/>
        <source>50 fps</source>
        <translation>50 fps</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="192"/>
        <source>25 fps</source>
        <translation>25 fps</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="198"/>
        <source>&amp;Show Title</source>
        <translation>&amp;Näytä nimike</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="201"/>
        <source>&amp;Full Screen</source>
        <translation>&amp;Koko näyttö</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="201"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>VisualGoomFactory</name>
    <message>
        <location filename="../visualgoomfactory.cpp" line="30"/>
        <source>Goom</source>
        <translation>Goom</translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="49"/>
        <source>About Goom Visual Plugin</source>
        <translation>Tietoja: Goom Visual Plugin</translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="50"/>
        <source>Qmmp Goom Visual Plugin</source>
        <translation>Qmmp Goom Visual Plugin</translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="51"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Kirjoittanut: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="52"/>
        <source>Based on the source code from the Goom project</source>
        <translation>Perustuu Goom-projektin lähdekoodiin</translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="53"/>
        <source>Goom project developers:</source>
        <translation>Goom-projektin kehittäjät:</translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="54"/>
        <source>Jean-Christophe Hoelt &lt;jeko@ios-software.com&gt;</source>
        <translation>Jean-Christophe Hoelt &lt;jeko@ios-software.com&gt;</translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="55"/>
        <source>Guillaume Borios &lt;gyom@ios-software.com&gt;</source>
        <translation>Guillaume Borios &lt;gyom@ios-software.com&gt;</translation>
    </message>
</context>
</TS>
